@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="hu" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
 <context>
     <name>App.About</name>
     <message>
@@ -770,6 +770,13 @@ Are you sure you want to continue?</source>
         <translation>Minden folyamat</translation>
     </message>
 </context>
+<context>
+    <name>Process.Loading</name>
+    <message>
+        <source>Loading</source>
+        <translation>Betöltés</translation>
+    </message>
+</context>
 <context>
     <name>Process.Signal</name>
     <message>
@@ -976,10 +983,12 @@ Are you sure you want to continue?</source>
     </message>
     <message>
         <source>OK</source>
+        <comment>button</comment>
         <translation>OK</translation>
     </message>
     <message>
         <source>Cancel</source>
+        <comment>button</comment>
         <translation>Mégsem</translation>
     </message>
 </context>
@@ -1101,4 +1110,4 @@ Are you sure you want to continue?</source>
         <translation>Szolgáltatások</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
