@@ -771,6 +771,13 @@ Continuar?</translation>
         <translation>Todos os processos</translation>
     </message>
 </context>
+<context>
+    <name>Process.Loading</name>
+    <message>
+        <source>Loading</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>Process.Signal</name>
     <message>
@@ -1102,4 +1109,4 @@ Continuar?</translation>
         <translation>Serviços</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
