@@ -1,4 +1,4 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="uk">
 <context>
     <name>App.About</name>
     <message>
@@ -769,6 +769,13 @@ Are you sure you want to continue?</source>
         <translation>Всі процеси</translation>
     </message>
 </context>
+<context>
+    <name>Process.Loading</name>
+    <message>
+        <source>Loading</source>
+        <translation>Завантаження</translation>
+    </message>
+</context>
 <context>
     <name>Process.Signal</name>
     <message>
@@ -975,10 +982,12 @@ Are you sure you want to continue?</source>
     </message>
     <message>
         <source>OK</source>
+        <comment>button</comment>
         <translation>Гаразд</translation>
     </message>
     <message>
         <source>Cancel</source>
+        <comment>button</comment>
         <translation>Скасувати</translation>
     </message>
 </context>
@@ -1100,4 +1109,4 @@ Are you sure you want to continue?</source>
         <translation>Служби</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
